@@ -218,7 +218,7 @@ instrument_names = (
     "recorder", # 74
     "pan flute", # 75
     "blown bottle", # 76
-    "skakuhachi", # 77
+    "shakuhachi", # 77
     "whistle", # 78
     "ocarina", # 79
     "lead 1 (square)", # 80
