@@ -24,10 +24,6 @@
 #include <unistd.h>
 #include <sys/ioctl.h>
 
-#ifdef HAVE_LINUX_AWE_VOICE_H
-#include <linux/awe_voice.h>
-#endif
-
 extern int _seqbufptr;
 extern int _seqbuflen;
 extern unsigned char _seqbuf[];
@@ -80,14 +76,4 @@ void seq_start_timer()
 #endif
   SEQ_START_TIMER();
 }
-#ifdef HAVE_LINUX_AWE_VOICE_H
-void awe_set_channel_mode(int devnum, int mode)
-{
-  AWE_SET_CHANNEL_MODE(devnum, mode);
-}
 
-void awe_drum_channels(int awe_dev, int ch)
-{
-  AWE_DRUM_CHANNELS(awe_dev, ch);
-}
-#endif
