@@ -54,40 +54,51 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.m_app = app
         self.g_notebook = gtk.Notebook()
         self.vbox.pack_start(self.g_notebook)
+        
+        tooltips = gtk.Tooltips()
+        
         ########
         # midi #
         ########
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("Instruments")))
 
         vbox, category_vbox = gu.hig_category_vbox(_("Tempo"))
         page_vbox.pack_start(vbox, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
+        tempo_hbox = gtk.HBox(spacing=6)
         self.g_default_bpm = gu.nSpinButton('config', 'default_bpm',
             gtk.Adjustment(self.get_int('config/default_bpm'), 10, 500, 1, 10))
-        box = gu.hig_label_widget(_("_Default bpm:"), self.g_default_bpm, sizegroup)
-        category_vbox.pack_start(box, False)
-
         self.g_arpeggio_bpm = gu.nSpinButton('config', 'arpeggio_bpm',
             gtk.Adjustment(self.get_int('config/arpeggio_bpm'), 10, 500, 1, 10))
-        box = gu.hig_label_widget(_("A_rpeggio bpm:"), self.g_arpeggio_bpm, sizegroup)
-        category_vbox.pack_start(box, False)
+        for text, widget in [("_Default:",self.g_default_bpm), ("A_rpeggio:",self.g_arpeggio_bpm)]:
+            label = gtk.Label(text)
+            label.set_alignment(0.0, 0.5)
+            label.set_use_underline(True)
+            tempo_hbox.pack_start(label, expand=False)
+            label.set_mnemonic_widget(widget)
+            tempo_hbox.pack_start(widget, expand=False)
+            label = gtk.Label(_("BPM"))
+            label.set_alignment(0.0, 0.5)
+            tooltips.set_tip(label, _("Beats per minute"))
+            tempo_hbox.pack_start(label, expand=True)        
+        category_vbox.pack_start(tempo_hbox, False)
 
-        box, category_vbox = gu.hig_category_vbox(_("Preferred instrument"))
+        box, category_vbox = gu.hig_category_vbox(_("Preferred Instrument"))
         page_vbox.pack_start(box, False)
         self.g_instrsel = nInstrumentSelector('config',
                         'preferred_instrument', sizegroup)
         category_vbox.pack_start(self.g_instrsel, False)
 
-        box, category_vbox = gu.hig_category_vbox(_("Chord instruments"))
+        box, category_vbox = gu.hig_category_vbox(_("Chord Instruments"))
         page_vbox.pack_start(box, False)
         self.g_instrument_configurator  \
               = InstrumentConfigurator("config", 3,
-                    _("Use different instruments for chords and harmonic intervals."))
+                    _("Use different instruments for chords and harmonic intervals"))
         category_vbox.pack_start(self.g_instrument_configurator, False)
 
-        vbox, category_box = gu.hig_category_vbox(_("Preferred percussion instruments"))
+        vbox, category_box = gu.hig_category_vbox(_("Percussion Instruments"))
         page_vbox.pack_start(vbox, False)
         category_box.pack_start(gu.hig_label_widget(
             _("Count in:"),
@@ -103,20 +114,20 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("User")))
 
-        box, category_vbox = gu.hig_category_vbox(_("User's voice"))
+        box, category_vbox = gu.hig_category_vbox(_("User's Vocal Range"))
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
         self.g_highest_singable = notenamespinbutton.NotenameSpinButton(
             self.get_string('user/highest_pitch'))
-        box = gu.hig_label_widget(_("Highest note user can sing:"),
+        box = gu.hig_label_widget(_("Highest pitch:"),
                                   self.g_highest_singable,
                                   sizegroup)
         category_vbox.pack_start(box)
 
         self.g_lowest_singable = notenamespinbutton.NotenameSpinButton(
             self.get_string('user/lowest_pitch'))
-        box = gu.hig_label_widget(_("Lowest note user can sing:"),
+        box = gu.hig_label_widget(_("Lowest pitch:"),
                                   self.g_lowest_singable,
                                   sizegroup)
         category_vbox.pack_start(box)
@@ -140,9 +151,9 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         # external programs #
         #####################
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("External programs")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("External Programs")))
 
-        box, category_vbox = gu.hig_category_vbox(_("Convertors"))
+        box, category_vbox = gu.hig_category_vbox(_("Converters"))
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
@@ -155,7 +166,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_wav_convertor.connect('changed', 
             lambda w: self.set_string('app/midi_to_wav_cmd', w.child.get_text()))
         category_vbox.pack_start(
-            gu.hig_label_widget(_("MIDI to WAV convertor:"),
+            gu.hig_label_widget(_("MIDI to WAV:"),
             self.g_wav_convertor, sizegroup))
         # wav_to_mp3
         liststore = gtk.ListStore(gobject.TYPE_STRING)
@@ -166,7 +177,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_mp3_convertor.connect('changed', 
             lambda w: self.set_string('app/wav_to_mp3_cmd', w.child.get_text()))
         category_vbox.pack_start(
-            gu.hig_label_widget(_("WAV to MP3 convertor:"),
+            gu.hig_label_widget(_("WAV to MP3:"),
             self.g_mp3_convertor, sizegroup))
         # wav_to_ogg
         liststore = gtk.ListStore(gobject.TYPE_STRING)
@@ -177,7 +188,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_ogg_convertor.connect('changed', 
             lambda w: self.set_string('app/wav_to_ogg_cmd', w.child.get_text()))
         category_vbox.pack_start(
-            gu.hig_label_widget(_("WAV to OGG convertor:"),
+            gu.hig_label_widget(_("WAV to OGG:"),
             self.g_ogg_convertor, sizegroup))
 
         self.add_gui_for_external_programs(page_vbox)
@@ -186,7 +197,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         ########
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
-        box, category_vbox = gu.hig_category_vbox(_("Misc"))
+        box, category_vbox = gu.hig_category_vbox(_("Miscellaneous"))
         page_vbox.pack_start(box, False)
 
         # CSound
@@ -196,7 +207,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_csound_exe = gtk.ComboBoxEntry(liststore)
         self.g_csound_exe.child.set_text(self.get_string("programs/csound"))
         self.g_csound_exe.connect('changed', lambda w: self.set_string('programs/csound', self.g_csound_exe.child.get_text()))
-        box = gu.hig_label_widget(_("CSound executable:"), self.g_csound_exe, sizegroup)
+        box = gu.hig_label_widget(_("CSound:"), self.g_csound_exe, sizegroup)
         category_vbox.pack_start(box)
         # MMA
         liststore = gtk.ListStore(gobject.TYPE_STRING)
@@ -205,7 +216,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_mma_exe = gtk.ComboBoxEntry(liststore)
         self.g_mma_exe.child.set_text(self.get_string("programs/mma"))
         self.g_mma_exe.connect('changed', lambda w: self.set_string('programs/mma', self.g_mma_exe.child.get_text()))
-        box = gu.hig_label_widget(_("MMA executable:"), self.g_mma_exe, sizegroup)
+        box = gu.hig_label_widget(_("Musical MIDI Accompaniment:"), self.g_mma_exe, sizegroup)
         category_vbox.pack_start(box)
         # Mail program
         liststore = gtk.ListStore(gobject.TYPE_STRING)
@@ -216,23 +227,23 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_mail_program = gtk.ComboBoxEntry(liststore)
         self.g_mail_program.child.set_text(self.get_string("config/mua"))
         self.g_mail_program.child.connect('changed', lambda w: self.set_string('config/mua', self.g_mail_program.child.get_text()))
-        box = gu.hig_label_widget(_("_Mail program:"), self.g_mail_program, sizegroup)
+        box = gu.hig_label_widget(_("_Mail:"), self.g_mail_program, sizegroup)
         category_vbox.pack_start(box)
 
         #######
         # Gui #
         #######
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Gui")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("Interface")))
 
-        box, category_vbox = gu.hig_category_vbox(_("Gui"))
+        box, category_vbox = gu.hig_category_vbox(_("User Interface"))
         page_vbox.pack_start(box, False)
 
         b = gu.nCheckButton('gui', 'web_browser_as_help_browser',
-            _("Use a _web browser as help browser"))
+            _("Use _web browser for online help"))
         category_vbox.pack_start(b, False)
         self.g_mainwin_user_resizeable = gu.nCheckButton('gui',
-          'mainwin_user_resizeable', _("_User resizeable main window"))
+          'mainwin_user_resizeable', _("_Resizeable main window"))
         category_vbox.pack_start(self.g_mainwin_user_resizeable, False)
 
         # Combobox to select language
@@ -301,14 +312,14 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.create_linux_sound_page()
         self.show_all()
     def add_gui_for_external_programs(self, page_vbox):
-        box, category_vbox = gu.hig_category_vbox(_("Audio players"))
+        box, category_vbox = gu.hig_category_vbox(_("Audio File Players"))
         page_vbox.pack_start(box, False)
         if sys.platform != 'win32':
             format_info = [
                 {'id': 'wav',
                  # testfile is a file in lesson-files/share
                  'testfile': 'fifth-small-220.00.wav',
-                 'label': _("WAV file player"),
+                 'label': _("WAV:"),
                  # players is a list of tuples. The tuple has to elements:
                  # '/path/to/player', 'comandline'
                  'players': [],
@@ -319,17 +330,17 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         format_info.extend([
             {'id': 'midi',
              'testfile': 'fanfare.midi',
-             'label': _("MIDI file player"),
+             'label': _("MIDI:"),
              'players': [],
             },
             {'id': 'mp3',
              'testfile': 'fanfare.mp3',
-             'label': _("MP3 file player"),
+             'label': _("MP3:"),
              'players': [],
             },
             {'id': 'ogg',
              'testfile': 'fanfare.ogg',
-             'label': _("OGG file player"),
+             'label': _("OGG:"),
              'players': [],
             },
         ])
@@ -389,11 +400,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.m_app.m_ui.display_exception_message(e)
     def create_linux_sound_page(self):
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Sound setup")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("Sound Setup")))
         #############
         # midi setup
         #############
-        box, category_vbox = gu.hig_category_vbox(_("Midi setup"))
+        box, category_vbox = gu.hig_category_vbox(_("MIDI Setup"))
         page_vbox.pack_start(box)
 
         self.g_fakesynth_radio = gu.RadioButton(None, _("_No sound"), None)
@@ -418,7 +429,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         ###
         hbox = gu.bHBox(category_vbox, False)
         self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
-             _("Use _external midiplayer"), None)
+             _("Use _external MIDI player"), None)
         hbox.pack_start(self.g_midiplayer_radio, False)
 
         if self.get_string("sound/type") == "external-midiplayer":
@@ -430,17 +441,17 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
 
         hbox = gtk.HButtonBox()
         category_vbox.pack_start(hbox)
-        gu.bButton(category_vbox, _("_Apply changes and play test sound"), self.on_apply_and_play_test_sound)
+        gu.bButton(category_vbox, _("_Test"), self.on_apply_and_play_test_sound)
 
     def create_win32_sound_page(self):
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi setup")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("MIDI Setup")))
         #############
         # midi setup
         #############
-        box, category_vbox = gu.hig_category_vbox(_("Sound setup"))
+        box, category_vbox = gu.hig_category_vbox(_("Sound Setup"))
         page_vbox.pack_start(box)
-        txt = gtk.Label(_("""Solfege has two ways to play midi files. It is recommended to use Windows multimedia output. An external midiplayer can be useful if your soundcard lacks a hardware synth, in which case you have to use a program like timidity to play the music."""))
+        txt = gtk.Label(_("""Solfege has two ways to play MIDI files. It is recommended to use Windows multimedia output. An external MIDI player can be useful if your soundcard lacks a hardware synth, in which case you have to use a program like timidity to play the music."""))
         txt.set_line_wrap(1)
         txt.set_justify(gtk.JUSTIFY_FILL)
         txt.set_alignment(0.0, 0.0)
@@ -467,7 +478,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
 
         hbox = gu.bHBox(category_vbox, False)
         self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
-             _("Use _external midiplayer"), None)
+             _("Use _external MIDI player"), None)
         hbox.pack_start(self.g_midiplayer_radio, False)
 
         if self.get_string("sound/type") == "external-midiplayer":
@@ -477,7 +488,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         else:
             self.g_fakesynth_radio.set_active(True)
 
-        gu.bButton(category_vbox, _("_Apply changes and play test sound"), self.on_apply_and_play_test_sound)
+        gu.bButton(category_vbox, _("_Test"), self.on_apply_and_play_test_sound)
     def set_gui_from_config(self):
         if self.get_string("sound/type") == "fake-synth":
             self.g_fakesynth_radio.set_active(True)
