@@ -52,12 +52,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_go_back = gtk.Button(stock='gtk-go-back')
         self.g_go_back.connect('clicked', self.select_previous)
         self.g_go_back.show()
-        self.g_go_back.get_children()[0].get_children()[0].get_children()[1].hide()
         self.action_area.pack_start(self.g_go_back, False)
         self.g_go_forward = b = gtk.Button(stock='gtk-go-forward')
         self.g_go_forward.show()
         self.g_go_forward.connect('clicked', self.select_next)
-        self.g_go_forward.get_children()[0].get_children()[0].get_children()[1].hide()
         self.action_area.pack_start(self.g_go_forward, False)
         self.g_play = gu.bButton(self.action_area, _("_Play the whole music"),
                                  self.play)
