@@ -167,10 +167,10 @@ class Gui(abstract.LessonbasedGui):
             self.show_progress()
     def show_progress(self):
         if self.m_t.m_answered_quality is not None:
-            s = str(mpd.Interval.nn_to_translated_quality(self.m_t.m_answered_quality)) + "..."
+            s = _(str(mpd.Interval.nn_to_translated_quality(self.m_t.m_answered_quality))) + "..."
         else:
             assert self.m_t.m_answered_number is not None
-            s = "... %s" % mpd.Interval.number_name(self.m_t.m_answered_number)
+            s = "... %s" % _(mpd.Interval.number_name(self.m_t.m_answered_number))
         self.g_flashbar.set(s)
     def handle_do_answer(self):
         self.g_flashbar.clear()
