@@ -4,6 +4,7 @@ import os
 import sys
 import re
 from subprocess import *
+import time
 
 def run(cmd):
     print "run:", cmd
@@ -18,28 +19,35 @@ def get_image_dim(fn):
     else:
         return None, None
 
-def do_file(fn):
+def do_file(fn, width):
+    time.sleep(2)
     f, ext = os.path.splitext(fn)
-    run("import -frame %s" % fn)
+    run("import %s" % fn)
     x, y = get_image_dim(fn)
-    if x > 510:
-        run("convert -scale 510 %s %s-resized.png" % (fn, f))
+    if not width:
+        width = 510
+    if x > width:
+        run("convert -scale %i %s %s-resized.png" % (width, fn, f))
         run("mv %s-resized.png %s" % (f, fn))
     run("pngquant -nofs 8 %s" % fn)
     run("mv %s-or8.png %s" % (f, fn))
 
 help = """
-Usage: ./tools/screenshot path/to/image.png
+Usage: ./tools/screenshot path/to/image.png [width]
 
 Make a screenshot using "import". Run this script, and then
 click on the window you want to make a screenshot of.
 """
-if len(sys.argv) != 2:
+if len(sys.argv) not in (2, 3):
     print help
     sys.exit()
 if sys.argv[1] in ('-h', '--help'):
     print help
     sys.exit()
 
-do_file(sys.argv[1])
-
+try:
+    width = int(sys.argv[2])
+except:
+    width = None
+do_file(sys.argv[1], width)
+print "Remember to use the Simple (Enkelt, nb_NO) theme."
